@@ -92,11 +92,12 @@ def add_tokens_to_log_filter(conf, additional_tokens=None):
                           "filter", token['name'])
                 parser = JinjaParser()
                 token_value = parser.parse(token['value'], True)
-                # nosec
-                if token_value == '':
+                if token_value == '':  # nosec B105
                     raise_ex(ValueError, f"Please set a value for token "
                                          f"{token['name']} in config file "
                                          "all.yml")
+                log.debug("add_tokens_to_log_filter - type of token value: %s",
+                          type(token_value))
                 token_list.append(token_value)
         # Add project tokens to filters
         if 'gitlab' in conf['defaults']:
@@ -107,8 +108,7 @@ def add_tokens_to_log_filter(conf, additional_tokens=None):
                     parser = JinjaParser()
                     token_value = parser.parse(str(project['trigger_token']),
                                                True)
-                    # nosec
-                    if token_value == '':
+                    if token_value == '':  # nosec B105
                         raise_ex(ValueError,
                                  "Please set a value for 'trigger_token' "
                                  f"of project {project_name} in config "
